@@ -1,4 +1,5 @@
-/* Copyright (c) Mark J. Kilgard, 1994. */
+
+/* Copyright (c) Mark J. Kilgard, 1994, 1997. */
 
 /* This program is freely distributable without licensing fees
    and is provided without guarantee or warrantee expressed or
@@ -7,18 +8,20 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+
+#if !defined(_WIN32)
 #include <X11/Xlib.h>
+#include <X11/Xatom.h>
+#endif
 
 /* SGI optimization introduced in IRIX 6.3 to avoid X server
    round trips for interning common X atoms. */
-#include <X11/Xatom.h>
 #if defined(_SGI_EXTRA_PREDEFINES) && !defined(NO_FAST_ATOMS)
 #include <X11/SGIFastAtom.h>
 #else
 #define XSGIFastInternAtom(dpy,string,fast_name,how) XInternAtom(dpy,string,how)
 #endif
 
-#include <GL/glut.h>
 #include "glutint.h"
 
 /* GLUT inter-file variables */
@@ -36,6 +39,7 @@ GLboolean __glutIconic = GL_FALSE;
 GLboolean __glutDebug = GL_FALSE;
 unsigned int __glutDisplayMode =
   GLUT_RGB | GLUT_SINGLE | GLUT_DEPTH;
+char *__glutDisplayString = NULL;
 int __glutConnectionFD;
 XSizeHints __glutSizeHints = {0};
 int __glutInitWidth = 300, __glutInitHeight = 300;
@@ -47,20 +51,74 @@ Atom __glutWMDeleteWindow;
 
 static Bool synchronize = False;
 
-#if defined(__vms)
-char *
-strdup(const char *string)
-{
-  char *new;
+#if defined(_WIN32)
 
-  new = malloc(strlen(string) + 1);
-  if (new == NULL)
-    return NULL;
-  strcpy(new, string);
-  return new;
-}
+#ifdef __BORLANDC__
+#include <float.h>  /* For masking floating point exceptions. */
 #endif
 
+void
+__glutOpenWin32Connection(char* display)
+{
+  static char *classname;
+  WNDCLASS  wc;
+  HINSTANCE hInstance = GetModuleHandle(NULL);
+  
+  /* Make sure we register the window only once. */
+  if(classname)
+    return;
+
+#ifdef __BORLANDC__
+  /* Under certain conditions (e.g. while rendering solid surfaces with
+     lighting enabled) Microsoft OpenGL libraries cause some illegal
+     operations like floating point overflow or division by zero. The
+     default behaviour of Microsoft compilers is to mask (ignore)
+     floating point exceptions, while Borland compilers do not.  The
+     following function of Borland RTL allows to mask exceptions.
+     Advice from Pier Giorgio Esposito (mc2172@mclink.it). */
+  _control87(MCW_EM,MCW_EM);
+#endif
+
+  classname = "GLUT";
+
+  /* Clear (important!) and then fill in the window class structure. */
+  memset(&wc, 0, sizeof(WNDCLASS));
+  wc.style         = CS_OWNDC;
+  wc.lpfnWndProc   = (WNDPROC)__glutWindowProc;
+  wc.hInstance     = hInstance;
+  wc.hIcon         = LoadIcon(hInstance, "GLUT_ICON");
+  wc.hCursor       = LoadCursor(hInstance, IDC_ARROW);
+  wc.hbrBackground = NULL;
+  wc.lpszMenuName  = NULL;
+  wc.lpszClassName = classname;
+
+  /* Fill in a default icon if one isn't specified as a resource. */
+  if(!wc.hIcon)
+    wc.hIcon = LoadIcon(NULL, IDI_WINLOGO);
+  
+  if(!RegisterClass(&wc)) {
+    __glutFatalError("RegisterClass() failed:"
+		     "Cannot register GLUT window class.");
+  }
+ 
+  __glutScreenWidth     = GetSystemMetrics(SM_CXSCREEN);
+  __glutScreenHeight    = GetSystemMetrics(SM_CYSCREEN);
+
+  /* Set the root window to NULL because windows creates a top-level
+     window when the parent is NULL.  X creates a top-level window
+     when the parent is the root window. */
+  __glutRoot            = NULL;
+
+  /* Set the display to 1 -- we shouldn't be using this anywhere
+     (except as an argument to X calls). */
+  __glutDisplay         = (Display*)1;
+
+  /* There isn't any concept of multiple screens in Win32, therefore,
+     we don't need to keep track of the screen we're on... it's always
+     the same one. */
+  __glutScreen          = 0;
+}
+#else /* !_WIN32 */
 void
 __glutOpenXConnection(char *display)
 {
@@ -85,6 +143,7 @@ __glutOpenXConnection(char *display)
   __glutWMDeleteWindow = XSGIFastInternAtom(__glutDisplay,
     "WM_DELETE_WINDOW", SGI_XA_WM_DELETE_WINDOW, False);
 }
+#endif /* _WIN32 */
 
 void
 __glutInitTime(struct timeval *beginning)
@@ -111,11 +170,11 @@ removeArgs(int *argcp, char **argv, int numToRemove)
   *argcp -= numToRemove;
 }
 
-void
+void APIENTRY 
 glutInit(int *argcp, char **argv)
 {
   char *display = NULL;
-  char *str;
+  char *str, *geometry = NULL;
   struct timeval unused;
   int i;
 
@@ -137,7 +196,7 @@ glutInit(int *argcp, char **argv)
   if (!__glutArgv)
     __glutFatalError("out of memory.");
   for (i = 0; i < __glutArgc; i++) {
-    __glutArgv[i] = strdup(argv[i]);
+    __glutArgv[i] = __glutStrdup(argv[i]);
     if (!__glutArgv[i])
       __glutFatalError("out of memory.");
   }
@@ -153,6 +212,9 @@ glutInit(int *argcp, char **argv)
   /* parse arguments for standard options */
   for (i = 1; i < __glutArgc; i++) {
     if (!strcmp(__glutArgv[i], "-display")) {
+#if defined(_WIN32)
+      __glutWarning("-display option invalid for win32 glut.");
+#endif
       if (++i >= __glutArgc) {
         __glutFatalError(
           "follow -display option with X display name.");
@@ -160,57 +222,25 @@ glutInit(int *argcp, char **argv)
       display = __glutArgv[i];
       removeArgs(argcp, &argv[1], 2);
     } else if (!strcmp(__glutArgv[i], "-geometry")) {
-      int flags, x, y, width, height;
-
       if (++i >= __glutArgc) {
         __glutFatalError(
           "follow -geometry option with geometry parameter.");
       }
-      /* Fix bogus "{width|height} may be used before set"
-         warning */
-      width = 0;
-      height = 0;
-
-      flags = XParseGeometry(__glutArgv[i], &x, &y,
-        (unsigned int *) &width, (unsigned int *) &height);
-      if (WidthValue & flags) {
-        /* Careful because X does not allow zero or negative
-           width windows */
-        if (width > 0)
-          __glutInitWidth = width;
-      }
-      if (HeightValue & flags) {
-        /* Careful because X does not allow zero or negative
-           height windows */
-        if (height > 0)
-          __glutInitHeight = height;
-      }
-      glutInitWindowSize(__glutInitWidth, __glutInitHeight);
-      if (XValue & flags) {
-        if (XNegative & flags)
-          x = DisplayWidth(__glutDisplay, __glutScreen) +
-            x - __glutSizeHints.width;
-        /* Play safe: reject negative X locations */
-        if (x >= 0)
-          __glutInitX = x;
-      }
-      if (YValue & flags) {
-        if (YNegative & flags)
-          y = DisplayHeight(__glutDisplay, __glutScreen) +
-            y - __glutSizeHints.height;
-        /* Play safe: reject negative Y locations */
-        if (y >= 0)
-          __glutInitY = y;
-      }
-      glutInitWindowPosition(__glutInitX, __glutInitY);
+      geometry = __glutArgv[i];
       removeArgs(argcp, &argv[1], 2);
     } else if (!strcmp(__glutArgv[i], "-direct")) {
+#if defined(_WIN32)
+      __glutWarning("-direct option invalid for win32 glut.");
+#endif
       if (!__glutTryDirect)
         __glutFatalError(
           "cannot force both direct and indirect rendering.");
       __glutForceDirect = GL_TRUE;
       removeArgs(argcp, &argv[1], 1);
     } else if (!strcmp(__glutArgv[i], "-indirect")) {
+#if defined(_WIN32)
+      __glutWarning("-indirect option invalid for win32 glut.");
+#endif
       if (__glutForceDirect)
         __glutFatalError(
           "cannot force both direct and indirect rendering.");
@@ -223,6 +253,9 @@ glutInit(int *argcp, char **argv)
       __glutDebug = GL_TRUE;
       removeArgs(argcp, &argv[1], 1);
     } else if (!strcmp(__glutArgv[i], "-sync")) {
+#if defined(_WIN32)
+      __glutWarning("-indirect option invalid for win32 glut.");
+#endif
       synchronize = GL_TRUE;
       removeArgs(argcp, &argv[1], 1);
     } else {
@@ -231,12 +264,57 @@ glutInit(int *argcp, char **argv)
       break;
     }
   }
+#if defined(_WIN32)
+  __glutOpenWin32Connection(display);
+#else
   __glutOpenXConnection(display);
+#endif
+  if (geometry) {
+    int flags, x, y, width, height;
+
+    /* Fix bogus "{width|height} may be used before set"
+       warning */
+    width = 0;
+    height = 0;
+
+    flags = XParseGeometry(geometry, &x, &y,
+      (unsigned int *) &width, (unsigned int *) &height);
+    if (WidthValue & flags) {
+      /* Careful because X does not allow zero or negative
+         width windows */
+      if (width > 0)
+        __glutInitWidth = width;
+    }
+    if (HeightValue & flags) {
+      /* Careful because X does not allow zero or negative
+         height windows */
+      if (height > 0)
+        __glutInitHeight = height;
+    }
+    glutInitWindowSize(__glutInitWidth, __glutInitHeight);
+    if (XValue & flags) {
+      if (XNegative & flags)
+        x = DisplayWidth(__glutDisplay, __glutScreen) +
+          x - __glutSizeHints.width;
+      /* Play safe: reject negative X locations */
+      if (x >= 0)
+        __glutInitX = x;
+    }
+    if (YValue & flags) {
+      if (YNegative & flags)
+        y = DisplayHeight(__glutDisplay, __glutScreen) +
+          y - __glutSizeHints.height;
+      /* Play safe: reject negative Y locations */
+      if (y >= 0)
+        __glutInitY = y;
+    }
+    glutInitWindowPosition(__glutInitX, __glutInitY);
+  }
   __glutInitTime(&unused);
 }
 
 /* CENTRY */
-void
+void APIENTRY 
 glutInitWindowPosition(int x, int y)
 {
   __glutInitX = x;
@@ -250,7 +328,7 @@ glutInitWindowPosition(int x, int y)
   }
 }
 
-void
+void APIENTRY 
 glutInitWindowSize(int width, int height)
 {
   __glutInitWidth = width;
@@ -264,7 +342,7 @@ glutInitWindowSize(int width, int height)
   }
 }
 
-void
+void APIENTRY 
 glutInitDisplayMode(unsigned int mask)
 {
   __glutDisplayMode = mask;
