@@ -9,7 +9,7 @@
 
 #include "glutint.h"
 
-void
+void APIENTRY 
 glutTabletMotionFunc(GLUTtabletMotionCB tabletMotionFunc)
 {
   __glutCurrentWindow->tabletMotion = tabletMotionFunc;
@@ -23,7 +23,7 @@ glutTabletMotionFunc(GLUTtabletMotionCB tabletMotionFunc)
   }
 }
 
-void
+void APIENTRY 
 glutTabletButtonFunc(GLUTtabletButtonCB tabletButtonFunc)
 {
   __glutCurrentWindow->tabletButton = tabletButtonFunc;
