@@ -91,10 +91,14 @@
 /* end of motion rate variables */
 
 /* start of motion  variables */
-#ifndef PI
-#define PI 3.141592654
+
+/* Some <math.h> files do not define M_PI... */
+#ifndef M_PI
+#define M_PI 3.14159265358979323846
 #endif
 
+GLUquadricObj *qobj;
+
 char leg = 0;
 
 int shoulder1 = 0, shoulder2 = 0, shoulder3 = 0, shoulder4 = 0, lat1 = 20, lat2 = 20,
@@ -595,7 +599,6 @@ void
 MechHip(char solid)
 {
   int i;
-  GLUquadricObj *hip[2];
 
   glNewList(SOLID_MECH_HIP, GL_COMPILE);
 #ifdef LIGHT
@@ -608,14 +611,13 @@ MechHip(char solid)
     if (i)
       glScalef(-1.0, 1.0, 1.0);
     glTranslatef(1.0, 0.0, 0.0);
-    hip[i] = gluNewQuadric();
 #ifdef LIGHT
     SetMaterial(mat_specular2, mat_ambient2, mat_diffuse2, mat_shininess2);
 #endif
     glColor3f(0.5, 0.5, 0.5);
     if (!solid)
-      gluQuadricDrawStyle(hip[i], GLU_LINE);
-    gluSphere(hip[0], 0.2, 16, 16);
+      gluQuadricDrawStyle(qobj, GLU_LINE);
+    gluSphere(qobj, 0.2, 16, 16);
     glTranslatef(-1.0, 0.0, 0.0);
   }
   glScalef(-1.0, 1.0, 1.0);
@@ -626,8 +628,6 @@ MechHip(char solid)
 void
 Shoulder(char solid)
 {
-  GLUquadricObj *deltoid = gluNewQuadric();
-
   glNewList(SOLID_MECH_SHOULDER, GL_COMPILE);
 #ifdef LIGHT
   SetMaterial(mat_specular, mat_ambient, mat_diffuse, mat_shininess);
@@ -641,8 +641,8 @@ Shoulder(char solid)
   glColor3f(0.5, 0.5, 0.5);
 #ifdef SPHERE
   if (!solid)
-    gluQuadricDrawStyle(deltoid, GLU_LINE);
-  gluSphere(deltoid, 0.6, 16, 16);
+    gluQuadricDrawStyle(qobj, GLU_LINE);
+  gluSphere(qobj, 0.6, 16, 16);
 #endif
   glTranslatef(-0.9, 0.0, 0.0);
   glEndList();
@@ -651,9 +651,6 @@ Shoulder(char solid)
 void
 UpperArm(char solid)
 {
-  GLUquadricObj *upper = gluNewQuadric();
-  GLUquadricObj *joint[2];
-  GLUquadricObj *joint1[2];
   int i;
 
   glNewList(SOLID_MECH_UPPER_ARM, GL_COMPILE);
@@ -669,8 +666,8 @@ UpperArm(char solid)
 #endif
   glColor3f(0.5, 0.5, 0.5);
   if (!solid)
-    gluQuadricDrawStyle(upper, GLU_LINE);
-  gluCylinder(upper, 0.4, 0.4, 1.5, 16, 10);
+    gluQuadricDrawStyle(qobj, GLU_LINE);
+  gluCylinder(qobj, 0.4, 0.4, 1.5, 16, 10);
 #ifdef LIGHT
   SetMaterial(mat_specular, mat_ambient, mat_diffuse, mat_shininess);
 #endif
@@ -679,23 +676,21 @@ UpperArm(char solid)
   glTranslatef(-0.4, -1.85, 0.0);
   glRotatef(90.0, 0.0, 1.0, 0.0);
   for (i = 0; i < 2; i++) {
-    joint[i] = gluNewQuadric();
     if (!solid)
-      gluQuadricDrawStyle(joint[i], GLU_LINE);
+      gluQuadricDrawStyle(qobj, GLU_LINE);
     if (i)
-      gluCylinder(joint[i], 0.5, 0.5, 0.8, 16, 10);
+      gluCylinder(qobj, 0.5, 0.5, 0.8, 16, 10);
     else
-      gluCylinder(joint[i], 0.2, 0.2, 0.8, 16, 10);
+      gluCylinder(qobj, 0.2, 0.2, 0.8, 16, 10);
   }
   for (i = 0; i < 2; i++) {
     if (i)
       glScalef(-1.0, 1.0, 1.0);
-    joint1[i] = gluNewQuadric();
     if (!solid)
-      gluQuadricDrawStyle(joint1[i], GLU_LINE);
+      gluQuadricDrawStyle(qobj, GLU_LINE);
     if (i)
       glTranslatef(0.0, 0.0, 0.8);
-    gluDisk(joint1[i], 0.2, 0.5, 16, 10);
+    gluDisk(qobj, 0.2, 0.5, 16, 10);
     if (i)
       glTranslatef(0.0, 0.0, -0.8);
   }
@@ -709,13 +704,6 @@ void
 VulcanGun(char solid)
 {
   int i;
-  GLUquadricObj *Barrel[5];
-  GLUquadricObj *BarrelFace[5];
-  GLUquadricObj *Barrel2[5];
-  GLUquadricObj *Barrel3[5];
-  GLUquadricObj *BarrelFace2[5];
-  GLUquadricObj *Mount = gluNewQuadric();
-  GLUquadricObj *Mount_face = gluNewQuadric();
 
   glNewList(SOLID_MECH_VULCAN, GL_COMPILE);
 
@@ -725,35 +713,25 @@ VulcanGun(char solid)
   glColor3f(0.5, 0.5, 0.5);
 
   if (!solid) {
-    gluQuadricDrawStyle(Mount, GLU_LINE);
-    gluQuadricDrawStyle(Mount_face, GLU_LINE);
+    gluQuadricDrawStyle(qobj, GLU_LINE);
   }
-  gluCylinder(Mount, 0.5, 0.5, 0.5, 16, 10);
+  gluCylinder(qobj, 0.5, 0.5, 0.5, 16, 10);
   glTranslatef(0.0, 0.0, 0.5);
-  gluDisk(Mount_face, 0.0, 0.5, 16, 10);
+  gluDisk(qobj, 0.0, 0.5, 16, 10);
 
   for (i = 0; i < 5; i++) {
-    Barrel[i] = gluNewQuadric();
-    BarrelFace[i] = gluNewQuadric();
-    BarrelFace2[i] = gluNewQuadric();
-    Barrel2[i] = gluNewQuadric();
-    Barrel3[i] = gluNewQuadric();
     glRotatef(72.0, 0.0, 0.0, 1.0);
     glTranslatef(0.0, 0.3, 0.0);
     if (!solid) {
-      gluQuadricDrawStyle(Barrel[i], GLU_LINE);
-      gluQuadricDrawStyle(BarrelFace[i], GLU_LINE);
-      gluQuadricDrawStyle(BarrelFace2[i], GLU_LINE);
-      gluQuadricDrawStyle(Barrel2[i], GLU_LINE);
-      gluQuadricDrawStyle(Barrel3[i], GLU_LINE);
+      gluQuadricDrawStyle(qobj, GLU_LINE);
     }
-    gluCylinder(Barrel[i], 0.15, 0.15, 2.0, 16, 10);
-    gluCylinder(Barrel3[i], 0.06, 0.06, 2.0, 16, 10);
+    gluCylinder(qobj, 0.15, 0.15, 2.0, 16, 10);
+    gluCylinder(qobj, 0.06, 0.06, 2.0, 16, 10);
     glTranslatef(0.0, 0.0, 2.0);
-    gluDisk(BarrelFace[i], 0.1, 0.15, 16, 10);
-    gluCylinder(Barrel2[i], 0.1, 0.1, 0.1, 16, 5);
+    gluDisk(qobj, 0.1, 0.15, 16, 10);
+    gluCylinder(qobj, 0.1, 0.1, 0.1, 16, 5);
     glTranslatef(0.0, 0.0, 0.1);
-    gluDisk(BarrelFace2[i], 0.06, 0.1, 16, 5);
+    gluDisk(qobj, 0.06, 0.1, 16, 5);
     glTranslatef(0.0, -0.3, -2.1);
   }
   glEndList();
@@ -785,9 +763,6 @@ void
 UpperLeg(char solid)
 {
   int i;
-  GLUquadricObj *Hamstring = gluNewQuadric();
-  GLUquadricObj *Knee = gluNewQuadric();
-  GLUquadricObj *joint[2];
 
   glNewList(SOLID_MECH_UPPER_LEG, GL_COMPILE);
 #ifdef LIGHT
@@ -795,8 +770,7 @@ UpperLeg(char solid)
 #endif
   glColor3f(1.0, 1.0, 0.0);
   if (!solid) {
-    gluQuadricDrawStyle(Hamstring, GLU_LINE);
-    gluQuadricDrawStyle(Knee, GLU_LINE);
+    gluQuadricDrawStyle(qobj, GLU_LINE);
   }
   glTranslatef(0.0, -1.0, 0.0);
   Box(0.4, 1.0, 0.7, solid);
@@ -815,7 +789,7 @@ UpperLeg(char solid)
   SetMaterial(mat_specular2, mat_ambient2, mat_diffuse2, mat_shininess2);
 #endif
   glColor3f(0.5, 0.5, 0.5);
-  gluCylinder(Hamstring, 0.6, 0.6, 3.0, 16, 10);
+  gluCylinder(qobj, 0.6, 0.6, 3.0, 16, 10);
 #ifdef LIGHT
   SetMaterial(mat_specular, mat_ambient, mat_diffuse, mat_shininess);
 #endif
@@ -830,16 +804,15 @@ UpperLeg(char solid)
   SetMaterial(mat_specular2, mat_ambient2, mat_diffuse2, mat_shininess2);
 #endif
   glColor3f(0.5, 0.5, 0.5);
-  gluCylinder(Knee, 0.8, 0.8, 1.8, 16, 10);
+  gluCylinder(qobj, 0.8, 0.8, 1.8, 16, 10);
   for (i = 0; i < 2; i++) {
     if (i)
       glScalef(-1.0, 1.0, 1.0);
-    joint[i] = gluNewQuadric();
     if (!solid)
-      gluQuadricDrawStyle(joint[i], GLU_LINE);
+      gluQuadricDrawStyle(qobj, GLU_LINE);
     if (i)
       glTranslatef(0.0, 0.0, 1.8);
-    gluDisk(joint[i], 0.0, 0.8, 16, 10);
+    gluDisk(qobj, 0.0, 0.8, 16, 10);
     if (i)
       glTranslatef(0.0, 0.0, -1.8);
   }
@@ -866,8 +839,6 @@ void
 LowerLeg(char solid)
 {
   float k, l;
-  GLUquadricObj *ankle = gluNewQuadric();
-  GLUquadricObj *ankle_face[2];
 
 #ifdef LIGHT
   SetMaterial(mat_specular, mat_ambient, mat_diffuse, mat_shininess);
@@ -892,9 +863,6 @@ LowerLeg(char solid)
         glutWireSphere(0.2, 16, 10);
       else
         glutSolidSphere(0.2, 16, 10);
-      /* joints[i] = gluNewQuadric();
-         if(!solid)gluQuadricDrawStyle(joints[i], GLU_LINE);
-         gluSphere(joints[i],0.2, 16, 16); i++; */
 #endif
       if (leg)
         glRotatef((GLfloat) heel1, 1.0, 0.0, 0.0);
@@ -917,9 +885,6 @@ LowerLeg(char solid)
         glutWireSphere(0.2, 16, 10);
       else
         glutSolidSphere(0.2, 16, 10);
-      /* joints[i] = gluNewQuadric();
-         if(!solid)gluQuadricDrawStyle(joints[i], GLU_LINE);
-         gluSphere(joints[i], 0.2, 16, 16);      i++; */
 #endif
       if (leg)
         glRotatef((GLfloat) - heel1, 1.0, 0.0, 0.0);
@@ -941,17 +906,16 @@ LowerLeg(char solid)
           glRotatef((GLfloat) ankle2, 1.0, 0.0, 0.0);
         glRotatef(90.0, 0.0, 1.0, 0.0);
         if (!solid)
-          gluQuadricDrawStyle(ankle, GLU_LINE);
-        gluCylinder(ankle, 0.8, 0.8, 1.8, 16, 10);
+          gluQuadricDrawStyle(qobj, GLU_LINE);
+        gluCylinder(qobj, 0.8, 0.8, 1.8, 16, 10);
         for (j = 0; j < 2; j++) {
-          ankle_face[j] = gluNewQuadric();
           if (!solid)
-            gluQuadricDrawStyle(ankle_face[j], GLU_LINE);
+            gluQuadricDrawStyle(qobj, GLU_LINE);
           if (j) {
             glScalef(-1.0, 1.0, 1.0);
             glTranslatef(0.0, 0.0, 1.8);
           }
-          gluDisk(ankle_face[j], 0.0, 0.8, 16, 10);
+          gluDisk(qobj, 0.0, 0.8, 16, 10);
           if (j)
             glTranslatef(0.0, 0.0, -1.8);
         }
@@ -970,8 +934,6 @@ RocketPod(char solid)
 {
 
   int i, j, k = 0;
-  GLUquadricObj *rocket[6];
-  GLUquadricObj *rocket1[6];
 
   glNewList(SOLID_MECH_ROCKET, GL_COMPILE);
 #ifdef LIGHT
@@ -996,24 +958,21 @@ RocketPod(char solid)
   glTranslatef(-0.5, -1.0, 1.3);
   for (i = 0; i < 2; i++) {
     for (j = 0; j < 3; j++) {
-      rocket[k] = gluNewQuadric();
-      rocket1[k] = gluNewQuadric();
       if (!solid) {
-        gluQuadricDrawStyle(rocket[k], GLU_LINE);
-        gluQuadricDrawStyle(rocket1[k], GLU_LINE);
+        gluQuadricDrawStyle(qobj, GLU_LINE);
       }
       glTranslatef(i, j, 0.6);
 #ifdef LIGHT
       SetMaterial(mat_specular3, mat_ambient3, mat_diffuse3, mat_shininess3);
 #endif
       glColor3f(1.0, 1.0, 1.0);
-      gluCylinder(rocket[k], 0.4, 0.4, 0.3, 16, 10);
+      gluCylinder(qobj, 0.4, 0.4, 0.3, 16, 10);
       glTranslatef(0.0, 0.0, 0.3);
 #ifdef LIGHT
       SetMaterial(mat_specular4, mat_ambient4, mat_diffuse4, mat_shininess4);
 #endif
       glColor3f(0.0, 1.0, 0.0);
-      gluCylinder(rocket1[k], 0.4, 0.0, 0.5, 16, 10);
+      gluCylinder(qobj, 0.4, 0.0, 0.5, 16, 10);
       k++;
       glTranslatef(-i, -j, -0.9);
     }
@@ -1247,6 +1206,7 @@ myinit(void)
 {
   char i = 1;
 
+  qobj = gluNewQuadric();
 #ifdef LIGHT
   SetMaterial(mat_specular2, mat_ambient2, mat_diffuse2, mat_shininess2);
 #endif
@@ -1287,9 +1247,9 @@ animation_walk(void)
     if (frame >= 0.0 && frame <= 21.0) {
       if (frame == 0.0)
         frame = 3.0;
-      angle = (180 / PI) * (acos(((cos((PI / 180) * frame) * 2.043) + 1.1625) / 3.2059));
+      angle = (180 / M_PI) * (acos(((cos((M_PI / 180) * frame) * 2.043) + 1.1625) / 3.2059));
       if (frame > 0) {
-        elevation = -(3.2055 - (cos((PI / 180) * angle) * 3.2055));
+        elevation = -(3.2055 - (cos((M_PI / 180) * angle) * 3.2055));
       } else
         elevation = 0.0;
       if (step == 0) {
@@ -1332,9 +1292,9 @@ animation_walk(void)
   if (step == 1 || step == 3) {
     /* for(x=21.0; x>=0.0; x=x-3.0){ */
     if (frame <= 21.0 && frame >= 0.0) {
-      angle = (180 / PI) * (acos(((cos((PI / 180) * frame) * 2.043) + 1.1625) / 3.2029));
+      angle = (180 / M_PI) * (acos(((cos((M_PI / 180) * frame) * 2.043) + 1.1625) / 3.2029));
       if (frame > 0)
-        elevation = -(3.2055 - (cos((PI / 180) * angle) * 3.2055));
+        elevation = -(3.2055 - (cos((M_PI / 180) * angle) * 3.2055));
       else
         elevation = 0.0;
       if (step == 1) {
