@@ -3,7 +3,14 @@
 #include <stdlib.h>
 #include <math.h>
 #include <string.h>
+#ifdef _WIN32
+#include "win32_dirent.h"
+/* Have to #undef LoadMenu or else Microsoft VC++ won't allow us to
+   redefine it. */
+#undef LoadMenu
+#else
 #include <dirent.h>
+#endif
 #include <assert.h>
 
 #include "walker.h"
@@ -865,6 +872,7 @@ void CurveMenuInit(void)
   glutAddMenuEntry("Toggle horizontals", CMENU_HORIZ);
   glutAddMenuEntry("Toggle walking", CMENU_WALK);
   glutAddMenuEntry("Quit", CMENU_QUIT);
+  glutSetWindow(CurveWindow);
   glutAttachMenu(GLUT_RIGHT_BUTTON);
 }
 
@@ -1006,6 +1014,7 @@ void GuyMenuInit(void)
   glutAddMenuEntry("Toggle Axes",    GMENU_AXES);
   glutAddMenuEntry("Toggle Perspective View", GMENU_PERSP);
   glutAddMenuEntry("Quit",           GMENU_QUIT);
+  glutSetWindow(GuyWindow);
   glutAttachMenu(GLUT_RIGHT_BUTTON);
 }
 
@@ -1015,11 +1024,9 @@ void GuyMenuInit(void)
 
 void RedisplayBoth(void)
 {
-  glutSetWindow(GuyWindow);
-  glutPostRedisplay();
+  glutPostWindowRedisplay(GuyWindow);
   if (CurveWindowVisible) {
-    glutSetWindow(CurveWindow);
-    glutPostRedisplay();
+    glutPostWindowRedisplay(CurveWindow);
   }
 }
 
